### rjj (read-joint-jet)
rjj is a simple cmd-based data cleaning tool
#### install it via (pip/pip3):
```
pip install rjj
```
#### update rjj
```
pip install rjj --upgrade
```
#### check current version
```
rjj -v
```
#### read user manual
```
rjj -h
```
### jointer and splitter
joint or split your csv file(s)
#### jointer
```
rjj j
```
#### splitter
```
rjj s
```